# eric7.Preferences.ConfigurationPages.EditorMouseClickHandlerPage

Module implementing the Editor Mouse Click Handlers configuration page.

### Global Attributes

None

### Classes

EditorMouseClickHandlerPage | Class implementing the Editor Mouse Click Handlers configuration page.

### Functions

create | Module function to create the configuration page.

## EditorMouseClickHandlerPage

Class implementing the Editor Mouse Click Handlers configuration page.

### Derived from

ConfigurationPageBase, Ui_EditorMouseClickHandlerPage

### Class Attributes

None

### Class Methods

None

### Methods

EditorMouseClickHandlerPage | Constructor
save | Public slot to save the Editor Mouse Click Handlers configuration.

### Static Methods

None

#### EditorMouseClickHandlerPage (Constructor)

EditorMouseClickHandlerPage()

Constructor

#### EditorMouseClickHandlerPage.save

save()

Public slot to save the Editor Mouse Click Handlers configuration.

Up

## create

create(_dlg)

Module function to create the configuration page.

_dlg (ConfigurationDialog)
  reference to the configuration dialog (unused)

Return:
  reference to the instantiated page

Return Type:
  ConfigurationPageBase

Up